﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using ZedGraph;

namespace netvis
{
   class NetworkInterface
    {
       protected String name;
       public string interfaceName
       {
           get { return String.Copy(name); }
       }
       protected List<TimeSpan> roots;
        public NetworkInterface(string name) {
            this.name = name;
            roots = new List<TimeSpan>();
        }
        public override string ToString()
        {
            return name;
        }
        public void addRoot(TimeSpan root) {
            roots.Add(root);
        }
        public PointPairList getTimeDevs(TimeSpan target)
        {
            PointPairList points = new PointPairList();
            foreach (TimeSpan root in roots) {
                points = getRec(points, root, target);
            }
            return points;

        }
        public PointPairList getRec(PointPairList points, TimeSpan root, TimeSpan target)
        {
            DateTime epoch = new DateTime(1900, 1, 1);
            if (root.GetType() == target.GetType())
            {
                points.Add(new PointPair((root.startTime - epoch).TotalDays, root.total));
                return points;
            }
            else
            {
                foreach (DateTime time in root.getSubtress().Keys)
                {
                    points = getRec(points, root.getSubtress()[time], target);
                }
                return points;
            }
        }
        public int getTotalAllow()
        {
            int total = 0;
            foreach (TimeSpan node in roots)
            {
                total += node.numberAllow;
            }
            return total;
        }
        public int getTotalBlock()
        {
            int total = 0;
            foreach (TimeSpan node in roots)
            {
                total += node.numberBlock;
            }
            return total;
        }
       public DateTime getEarliestTime(){
           DateTime ealist = DateTime.MaxValue;
           foreach (TimeSpan node in roots)
           {
               DateTime time = node.findEarliest();
               if (time < ealist)
               {
                   ealist = time;
               }
           }
           return ealist;
       }
       public DateTime getLatestTime()
       {
           DateTime latest = DateTime.MinValue;
           foreach (TimeSpan node in roots)
           {
               DateTime time = node.findLatest();
               if (time > latest)
               {
                   latest = time;
               }
           }
           return latest;
       }
       public List<Packet> getAllPackets() {
           List<Packet> list = new List<Packet>();
           foreach (TimeSpan node in roots) {
               list.AddRange(node.getAllPackets());
           }
           return list;
       }
   }
    
}
